@@ -1,3 +1,5 @@
+/* $Id: parameter.c,v 1.13 2004/12/23 21:50:41 bdejean Exp $ */
+
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -19,10 +21,8 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <config.h>
 #include <glibtop.h>
 #include <glibtop/parameter.h>
-#include <glibtop/error.h>
 
 #define _write_data(ptr,size)	\
 	if ((data_ptr == NULL) || (data_size < size)) return -size; \
