@@ -1,3 +1,5 @@
+/* $Id: procmem.c,v 1.14 2003/10/19 16:55:49 carlos Exp $ */
+
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -19,7 +21,6 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <config.h>
 #include <glibtop.h>
 #include <glibtop/procmem.h>
 
@@ -28,7 +29,7 @@ static const unsigned long _glibtop_sysdeps_proc_mem = 0;
 /* Init function. */
 
 void
-_glibtop_init_proc_mem_s (glibtop *server)
+glibtop_init_proc_mem_s (glibtop *server)
 {
 	server->sysdeps.proc_mem = _glibtop_sysdeps_proc_mem;
 }
